stts = {}
stts["all"] = ["NN", "NE", "ADJA", "ADJD", "CARD", "VMFIN", "VAFIN", "VVFIN", "VAIMP", "VVIMP", "VVINF", "VAINF", "VMINF", "VVIZU", "VVPP", "VMPP", "VAPP", "ART", "PPER", "PRF", "PPOSAT", "PPOSS", "PDAT", "PDS", "PIAT", "PIDAT", "PIS", "PRELAT", "PRELS", "PWAT", "PWS", "PWAV", "PAV", "ADV", "KOUI", "KOUS", "KON", "KOKOM", "APPR", "APPRART", "APPO", "APZR", "PTKZU", "PTKNEG", "PTKVZ", "PTKA", "PTKANT", "ITJ", "TRUNC", "XY", "FM"]
stts["nouns"] = ["NN", "NE"]
stts["adjectives"] = ["ADJA", "ADJD"]
stts["numbers"] = ["CARD"]
stts["verbs"] = ["VMFIN", "VAFIN", "VVFIN", "VAIMP", "VVIMP", "VVINF", "VAINF", "VMINF", "VVIZU", "VVPP", "VMPP", "VAPP"]
stts["articles"] = ["ART"]
stts["pronouns"] = ["PPER", "PRF", "PPOSAT", "PPOSS", "PDAT", "PDS", "PIAT", "PIDAT", "PIS", "PRELAT", "PRELS", "PWAT", "PWS", "PWAV", "PAV"]
stts["adverb"] = ["ADV"]
stts["conjunctions"] = [ "KOUI", "KOUS", "KON", "KOKOM"]
stts["adpositions"] = ["APPR", "APPRART", "APPO", "APZR"]
stts["particle"] = ["PTKZU", "PTKNEG", "PTKVZ", "PTKA", "PTKANT"]
stts["misc"] = ["ITJ", "TRUNC", "XY", "FM"]

sttsColors = {}
sttsColors["NN"] = "#ed1c24"
sttsColors["NE"] = "#8b0000"
sttsColors["ADJA"] = "#cd5c5c"
sttsColors["ADJD"] = "#ccf"
sttsColors["CARD"] = "#89cff0"
sttsColors["VMFIN"] = "#4169e1"
sttsColors["VAFIN"] = "#d6cadd"
sttsColors["VVFIN"] = "#ca2c92"
sttsColors["VAIMP"] = "#d3d3d3"
sttsColors["VVIMP"] = "#b06500"
sttsColors["VVINF"] = "#96c8a2"
sttsColors["VAINF"] = "#c72c48"
sttsColors["VMINF"] = "#fe28a2"
sttsColors["VVIZU"] = "#ffb6c1"
sttsColors["VVPP"] = "#0f4d92"
sttsColors["VMPP"] = "#353839"
sttsColors["VAPP"] = "#062a78"
sttsColors["ART"] = "#555d50"
sttsColors["PPER"] = "#873260"
sttsColors["PRF"] = "#922724"
sttsColors["PPOSAT"] = "#c89"
sttsColors["PPOSS"] = "#f5f5f5"
sttsColors["PDAT"] = "#d9004c"
sttsColors["PDS"] = "#f77fbe"
sttsColors["PIAT"] = "#8f00ff"
sttsColors["PIDAT"] = "#5b92e5"
sttsColors["PIS"] = "#704214"
sttsColors["PRELAT"] = "#0072bb"
sttsColors["PRELS"] = "#78184a"
sttsColors["PWAT"] = "#b03060"
sttsColors["PWS"] = "#0095b6"
sttsColors["PWAV"] = "#ff6"
sttsColors["PAV"] = "#93c572"
sttsColors["ADV"] = "#8b8589"
sttsColors["KOUI"] = "#1034a6"
sttsColors["KOUS"] = "#4b5320"
sttsColors["KON"] = "#fcf75e"
sttsColors["KOKOM"] = "#ca2c92"
sttsColors["APPR"] = "#f6c"
sttsColors["APPRART"] = "#b76e79"
sttsColors["APPO"] = "#bf94e4"
sttsColors["APZR"] = "#bb3385"
sttsColors["PTKZU"] = "#fefe33"
sttsColors["PTKNEG"] = "#987654"
sttsColors["PTKVZ"] = "#32cd32"
sttsColors["PTKA"] = "#4166f5"
sttsColors["PTKANT"] = "#ffc87c"
sttsColors["ITJ"] = "#7df9ff"
sttsColors["TRUNC"] = "#c19a6b"
sttsColors["XY"] = "#ffcba4"
sttsColors["FM"] = "#73c2fb"


#!/usr/bin/env python

__author__ = "Tom Zastrow"
__copyright__ = "Copyright 2022, Tom Zastrow"
__credits__ = ["Tom Zastrow"]
__license__ = "GPL"
__version__ = "3"
__maintainer__ = "Tom Zastrow"
__email__ = "thomas.zastrow@mpcdf.mpg.de"
__status__ = "Development"

from elasticsearch import Elasticsearch
from elasticsearch import RequestsHttpConnection
import lateco.Items as WP

class Queries(object):
    def __init__(self, url, port, user, pwd):
        self.cursor = Elasticsearch([url + ":" + str(port)], http_auth=(user, pwd), timeout=300, connection_class=RequestsHttpConnection,use_ssl=True, verify_certs=False)


    def getDoc(self, ind, id):
        theDoc = self.cursor.get(index=ind, id=id)
        return theDoc




    def match(self, ind, layer, query, size, source):
        q = {
            "query": {
                "match": {
                    layer: query,
                }
            },
            "size": size,
            "_source": source
        }
        res = self.cursor.search(index=ind, body=q)
        return res

    def matchPhrase(self, ind, layer, query, slop, size, source):
        q = {
            "query": {
                "match_phrase": {
                    layer: {
                        "query": query,
                        "slop": slop
                    }
                },                
            },
            
            "size": size,
            "_source": source,
            "track_total_hits": True
        }

        res = self.cursor.search(index=ind, body=q)

        return res

    def matchPhraseScroll(self, ind, layer, query, slop):
        q = {
            "query": {
                "match_phrase": {
                    layer: {
                        "query": query,
                        "slop": slop
                    }
                },                
            },
            "_source": True,
            "track_total_hits": True
        }

        res = self.cursor.search(index=ind, body=q, scroll = '2m', size=1000)
        sid = res['_scroll_id']
        scroll_size = res['hits']['total']['value']        
        
        pages = []
        for p in res["hits"]["hits"]:
                pages.append(p)
        
        while (scroll_size > 0):
            page = self.cursor.scroll(scroll_id = sid, scroll = '2m')
            for p in page["hits"]["hits"]:
                pages.append(p)

            sid = page['_scroll_id']
            scroll_size = len(page['hits']['hits'])

        return pages

class Result():
    def __init__(self, result):
        #self, id, score, subcorpus, articleId, token, lemma, pos
        
        self.id = result["_id"]
        self.score = result["_score"]
        self.subcorpus = result["_source"]["subcorpus"]
        self.articleId = result["_source"]["article"]

        self.sentence = WP.Sentence()
        token = result["_source"]["token"].split(" ")
        lemma = result["_source"]["lemma"].split(" ")
        pos = result["_source"]["pos"].split(" ")

        for i in range(0, len(token)):
            t = WP.Token(token[i], lemma[i], pos[i], "", "")
            self.sentence.tokens.append(t)

if __name__ == "__main__":
    print("These are objects for the lateco framework, call them from your own applications!")



#!/usr/bin/env python

__author__ = "Tom Zastrow"
__copyright__ = "Copyright 2022, Tom Zastrow"
__credits__ = ["Tom Zastrow"]
__license__ = "GPL"
__version__ = "3"
__maintainer__ = "Tom Zastrow"
__email__ = "thomas.zastrow@mpcdf.mpg.de"
__status__ = "Development"

import os

class Token(object):
    def __init__(self, token, lemma, pos, isAlpha, isStop):
        self.token = token
        self.lemma = lemma
        self.pos = pos
        self.isAlpha = isAlpha
        self.isStop = isStop
    
    def display(self):
        print(self.token, self.lemma, self.pos, self.isAlpha, self.isStop)

class Sentence(object):
    def __init__(self):
        self.tokens =  []

    def display(self):
        for t in self.tokens:
            t.display()

    def displayAsTokens(self):
        for t in self.tokens:
            print(t.token, end=" ")
        print()

    def bagOfWords(self, annotation):
        b = set()
        for t in self.tokens:
            if annotation == "token":
                b.add(t.token)
            if annotation == "lemma":
                b.add(t.lemma)
            if annotation == "pos":
                b.add(t.pos)
        return b

    def toString(self, annotation):
        temp = ""

        if annotation == "token":
            for t in self.tokens:
                temp = temp + t.token + " "

        if annotation == "lemma":
            for t in self.tokens:
                temp = temp + t.lemma + " "

        if annotation == "pos":
            for t in self.tokens:
                temp = temp + t.pos + " "

        temp = temp[:-1]
        return temp

class Article(object):
    def __init__(self, id, url, title):
        self.id = id
        self.url = url
        self.title = title
        self.sentences = []

    def bagOfWords(self, annotation):
        b = set()
        for s in self.sentences:
            b = b.union(b, s.bagOfWords(annotation))
        return b

    def display(self):
        print("ID: ", str(self.id))
        print("Title: ", str(self.title))
        print("URL: ", str(self.url))
        print()
        for s in self.sentences:
            s.display()

class Subcorpus(object):
    def __init__ (self, infile):
        self.articles = []  
        self.statistics = {}  
        self.name = infile.split("/")[-1]
        self.filename = infile
        f = open(infile, "r", encoding="utf8")
        lines = f.readlines()
        f.close()

        self.articles = []

        for line in lines:
            if line.startswith("<doc id=\""):
                rec = line.split("\" ")
                id = int(rec[0].replace("<doc id=\"", ""))
                url = rec[1].replace("url=\"", "")
                title = rec[2].replace("title=\"", "").replace("\">", "").strip()
                a = Article(id, url, title) 
            elif line.startswith("</doc>"):
                self.articles.append(a)
              
            elif line.startswith("<s>"):
                s = Sentence()
            elif line.startswith("</s>"):
                a.sentences.append(s)
            else:
                rec = line.strip().split("\t")
                if len(rec) != 5:
                    print("Length of token line is not 5:", line)
                else:
                    t = Token(rec[0],rec[1],rec[2],rec[3],rec[4])
                    s.tokens.append(t)
        
        self.statistics["articles"] = len(self.articles)
        self.statistics["sentences"] = 0
        self.statistics["tokens"] = 0
        for a in self.articles:
            self.statistics["sentences"] = self.statistics["sentences"] + len(a.sentences)
            for s in a.sentences:
                self.statistics["tokens"] = self.statistics["tokens"] + len(s.tokens)


    def getName(self):
        return self.name

    def bagOfWords(self, annotation):
        b = set()
        for a in self.articles:
            b = b.union(b, a.bagOfWords(annotation))
        return b

    def getArticleByID(self, id):
        for a in self.articles:
            if a.id == id:
                return a
        return None

class Corpus(object):
    def __init__(self, basePath):
        self.basePath = basePath
        
    def getName(self):
        return self.name
    
    def setName(self,name):
        self.name = name

    def getSubcorpora(self):   
        liste = []
        for root, dirs, files in os.walk(self.basePath):
                path = root.split('/')
                for file in files:
                    liste.append(os.path.join(root, file))
        return liste
    
    def getFolderList(self):   
        liste = []
        for root, dirs, files in os.walk(self.basePath):
                path = root.split('/')
                for dir in dirs:
                    liste.append(os.path.join(dir))
        return liste
    
    def getSubcorporaOfFolder(self, folder):   
        liste = []
        folder = self.basePath + "/" + folder
        for root, dirs, files in os.walk(folder):
                path = root.split('/')
                for file in files:
                    liste.append(os.path.join(root, file))
        return liste

    def getFolders(self):
        return [d for d in os.listdir(self.basePath) if os.path.isdir(os.path.join(self.basePath, d))]

    def getArticleByPosition(self, position):
        rec = position.split("/")
        folder = rec[1]
        subcorpusPath = self.basePath + "/" + folder + "/" +  rec[2]
        artId = int(rec[3])
        subcorpus = Subcorpus(subcorpusPath)

        return subcorpus.getArticleByID(artId)




class Ner(object):
    basePath = ""
    def __init__(self, basePath):
        self.basePath = basePath


    def getNERbyArticle(self, position):
        rec = position.split("/")
        folder = rec[0]
        subcorpusPath = self.basePath + "/" + folder + "/" +  rec[1]
        artId = int(rec[2])
        print("Subcorpuspath: ", subcorpusPath)
        print("Article id: ", artId)

        infile = open(subcorpusPath, "r")
        lines = infile.readlines()
        infile.close()

        ners = {}
        ners["PER"] = {}
        ners["LOC"] = {}
        ners["ORG"] = {}
        ners["MISC"] = {}
        id = ""

        for line in lines:
            line = line.strip()
            if line.startswith("<doc id=\""):
                rec = line.split("\" ")
                id = int(rec[0].replace("<doc id=\"", ""))
                url = rec[1].replace("url=\"", "")
                title = rec[2].replace("title=\"", "").replace("\">", "").strip()
            elif line.startswith("</doc>"):
                if id == artId:
                    id = ""
                    break
            else:
                if id == artId:
                    rec = line.split("\t")
                    type = rec[3]
                    if rec[0] in ners[type]:
                        ners[type][rec[0]] = ners[type][rec[0]] + 1
                    else:
                        ners[type][rec[0]] = 1 

        return ners




class Position(object):
    corpus = ""
    folder = ""
    subcorpus = ""
    article = -1
    sentence = -1
    token = -1


    def getArticle(self):
        return self.corpus.strip("/") + "/" + self.folder.strip("/") + "/" + self.subcorpus.strip("/") + "/" + str(self.article).strip("/")
    
    def getSentence(self):
        return self.corpus.strip("/") + "/" + self.folder.strip("/") + "/" + self.subcorpus.strip("/") + "/" + str(self.article).strip("/") + "/" + str(self.sentence).strip("/")


    def toString(self):
        return self.corpus.strip("/") + "/" + self.folder.strip("/") + "/" + self.subcorpus.strip("/") + "/" + str(self.article).strip("/") + "/" + str(self.sentence) + "/" + str(self.token)

if __name__ == "__main__":
    print("These are objects for the lateco framework, call them from your own applications!")




#!/usr/bin/env/python3

import pandas as pd

class Word:
    lemma = ""
    pos = ""
    value = 0
    variants = []
    def toString(self):
        return self.lemma + "\t" + self.pos + "\t" + str(self.value) + "\t" + ",".join(self.variants)

class Sentiment:
    positiv = {}
    negativ = {}

    def df(self, whichOne):
        theDict = {}
        if whichOne == "positiv":
            theDict = self.positiv
        else:
            theDict = self.negativ

        theList = []
        for entry in theDict:
            word = theDict[entry]
            tempList = []
            tempList.append(word.lemma)
            tempList.append(word.pos)
            tempList.append(float(word.value))
            tempList.append(",".join(word.variants))
            theList.append(tempList)

            
        df = pd.DataFrame(theList, columns=["lemma", "pos", "value", "variants"])
        #df = df["value"].to_numeric()
        #df["value"] =df.to_numeric(df["value"])
        df = df.astype({"value": float}, errors='raise') 

        return df


    def readFile(self, filename):
        dic = {}

        infile = open(filename, encoding="utf-8", mode="r")
        lines = infile.readlines()
        infile.close()

        for line in lines:
            line = line.strip()
            rec = line.split("\t")

            word =  Word()
            word.lemma = rec[0].split("|")[0]
            word.pos = rec[0].split("|")[1]
            word.value = float(rec[1])
            if len(rec) == 3:
                word.variants = rec[2].split(",")
            else:
                word.variants = []
            dic[word.lemma] = word
        return dic    

    def __init__(self, posFile, negFile):
            self.positiv = self.readFile(posFile)
            self.negativ = self.readFile(negFile)

if __name__ == "__main__":
    sentiment = Sentiment("SentiWS_v1.8c_Positive.txt", "SentiWS_v1.8c_Negative.txt")
    print("Size positive:", len(sentiment.positiv))
    print("Size negativ:", len(sentiment.negativ))
    
    word = " "
    while word != "":
        word = input("Enter a word: ")
        if word in sentiment.positiv:
            print("Positiv: ", sentiment.positiv[word].toString())
        elif word in sentiment.negativ:
            print("Negativ: ", sentiment.negativ[word].toString())
        else:
            print("Word not found.")
        print("--------------------------")

    posdf = sentiment.df("positiv")
    print(posdf.head())
    print("Good bye.")


